@@ -31,3 +31,21 @@ def conditional_add(set_: set, *args: T, _condition: Condition = is_not_none) ->
     for value in args:
         if _condition(value):
             set_.add(value)
+
+
+def set_if(condition: bool, mapping: MutableMapping[str, Any], **kwargs: Any) -> None:
+    if condition:
+        for key, value in kwargs.items():
+            mapping[key] = value
+
+
+def append_if(condition: bool, list_: list[Any], *args: Any) -> None:
+    if condition:
+        for value in args:
+            list_.append(value)
+
+
+def add_if(condition: bool, set_: set[Any], *args: Any) -> None:
+    if condition:
+        for value in args:
+            set_.add(value)
