@@ -46,8 +46,8 @@ class EnhancedJSONEncoder(json.JSONEncoder):
                 raise TypeError("TypeError: datetime.datetime WITHOUT tzinfo is not JSON serializable")
         if isinstance(o, datetime.date | datetime.time):  # date or time or datetime
             return o.isoformat()
-        if isinstance(o, set):
-            return list(o)
+        if isinstance(o, set | frozenset):
+            return tuple(o)
         if isinstance(o, bytes):
             return f'data:application/octet-stream;base64,{base64.b64encode(o)}'
         if isinstance(o, Decimal):
